package Paws::RDSData::SqlParameter;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', request_name => 'name', traits => ['NameInRequest']);
  has TypeHint => (is => 'ro', isa => 'Str', request_name => 'typeHint', traits => ['NameInRequest']);
  has Value => (is => 'ro', isa => 'Paws::RDSData::Field', request_name => 'value', traits => ['NameInRequest']);
1;

### main pod documentation begin ###

=head1 NAME

Paws::RDSData::SqlParameter

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::RDSData::SqlParameter object:

  $service_obj->Method(Att1 => { Name => $value, ..., Value => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::RDSData::SqlParameter object:

  $result = $service_obj->Method(...);
  $result->Att1->Name

=head1 DESCRIPTION

A parameter used in a SQL statement.

=head1 ATTRIBUTES


=head2 Name => Str

  The name of the parameter.


=head2 TypeHint => Str

  A hint that specifies the correct object type for data type mapping.

B<Values:>

=over

=item *

C<DECIMAL> - The corresponding C<String> parameter value is sent as an
object of C<DECIMAL> type to the database.

=item *

C<TIMESTAMP> - The corresponding C<String> parameter value is sent as
an object of C<TIMESTAMP> type to the database. The accepted format is
C<YYYY-MM-DD HH:MM:SS[.FFF]>.

=item *

C<TIME> - The corresponding C<String> parameter value is sent as an
object of C<TIME> type to the database. The accepted format is
C<HH:MM:SS[.FFF]>.

=item *

C<DATE> - The corresponding C<String> parameter value is sent as an
object of C<DATE> type to the database. The accepted format is
C<YYYY-MM-DD>.

=back



=head2 Value => L<Paws::RDSData::Field>

  The value of the parameter.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::RDSData>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

